@@ -14,9 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -80,24 +79,22 @@ test_fixture_teardown (TestFixture   *fixture,
 }
 
 static void
-compare_strv_unordered (const gchar **strv,
-                        const gchar **expected_strv)
+compare_strv (const gchar **strv,
+	      const gchar **expected_strv)
 {
 	if (expected_strv != NULL)
 	{
-		guint i;
+		guint n, i;
 
-		g_assert_cmpuint (g_strv_length ((gchar **) strv), ==,
-				  g_strv_length ((gchar **) expected_strv));
-
-		for (i = 0; expected_strv[i] != NULL; i++)
+		n = g_strv_length ((gchar **) expected_strv);
+		for (i = 0; i < n; i++)
 		{
-			g_assert_true (g_strv_contains (strv, expected_strv[i]));
+			g_assert_cmpstr (strv[i], ==, expected_strv[i]);
 		}
 	}
 	else
 	{
-		g_assert_null (strv);
+		g_assert (strv == NULL);
 	}
 }
 
@@ -125,15 +122,15 @@ check_language (GtkSourceLanguage  *language,
 	g_assert_cmpstr (gtk_source_language_get_metadata (language, "extra-meta"), ==, expected_extra_meta);
 
 	mime = gtk_source_language_get_mime_types (language);
-	compare_strv_unordered ((const gchar **) mime, expected_mime);
+	compare_strv ((const gchar **) mime, expected_mime);
 	g_strfreev (mime);
 
 	glob = gtk_source_language_get_globs (language);
-	compare_strv_unordered ((const gchar **) glob, expected_glob);
+	compare_strv ((const gchar **) glob, expected_glob);
 	g_strfreev (glob);
 
 	styles = gtk_source_language_get_style_ids (language);
-	compare_strv_unordered ((const gchar **) styles, expected_styles);
+	compare_strv ((const gchar **) styles, expected_styles);
 	g_strfreev (styles);
 
 	if (expected_style_name != NULL)
